@@ -348,10 +348,12 @@ coxreg <- function (formula = formula(data),
         init <- 0
         if (FALSE){
         if (type == "counting"){
+            if (control$trace) cat("Running survival::agreg.fit\n")
             fit <- survival::agreg.fit(X, Y, stratum, offset, init,
                                         control, weights = weights,
                                         method = method, row.names(m))
         }else{
+            if (control$trace) cat("Running survival::coxph.fit\n")
             fit <- survival::coxph.fit(X, Y, stratum, offset, init,
                                         control, weights = weights,
                                         method = method, row.names(m))
@@ -386,10 +388,12 @@ coxreg <- function (formula = formula(data),
         if (is.null(strats)) stratum <- rep(1, NROW(Y))
         else stratum <- strats
         if (type == "counting"){
+            if (control$trace) cat("Running survival::agreg.fit\n")
             fit <- survival::agreg.fit(X, Y, stratum, offset, init,
                                         control, weights = weights,
                                         method = method, row.names(m))
         }else{
+            if (control$trace) cat("Running survival::coxph.fit\n")
             fit <- survival::coxph.fit(X, Y, stratum, offset, init,
                                         control, weights = weights,
                                         method = method, row.names(m))
